from typing import Dict, Union

from pydantic import ConfigDict
from pydantic_settings import BaseSettings, SettingsConfigDict


class CliConfig(ConfigDict):
    cli_enable_prefix: Union[str, Dict[str, str]]
    cli_disable_prefix: Union[str, Dict[str, str]]


CliConfigDict = CliConfig


class EnvCliConfig(SettingsConfigDict):
    cli_enable_prefix: Union[str, Dict[str, str]]
    cli_disable_prefix: Union[str, Dict[str, str]]


EnvCliConfigDict = EnvCliConfig



from pydantic_argify.__version__ import __version__
from pydantic_argify.cli import command, entrypoint, main, sub_command
from pydantic_argify.config import CliConfig, EnvCliConfig
from pydantic_argify.parse import build_parser

__all__ = [
    "build_parser",
    "main",
    "entrypoint",
    "command",
    "sub_command",
    "CliConfig",
    "EnvCliConfig",
    "__version__",
]
